(function (factory) {
	typeof define === 'function' && define.amd ? define(factory) :
	factory();
})((function () { 'use strict';

	Unknown.staticMember;
	Unknown.prototype.method;

}));
